@@ -24,9 +24,23 @@ from yams.buildobjs import (EntityType, RelationDefinition, SubjectRelation, Str
 from cubes.questionnaire.schema import QuestionnaireRun, Questionnaire, Question
 from cubes.neuroimaging.schema import Scan, AnatomicalRegion
 from cubes.genomics.schema import GenomicMeasure, ColumnRef
-from cubes.medicalexp.schema  import Assessment, ProcessingRun, ScoreDefinition, ScoreValue
+from cubes.medicalexp.schema  import (Assessment, ProcessingRun, ScoreDefinition, ScoreValue,
+                                      Diagnostic, TechnicalAnalysis)
 
-from cubes.brainomics import COMMENTED_ENTITIES, WIKI_ENTITIES
+
+# Diagnostic/TechnicalAnalysis
+Diagnostic.add_relation(SubjectRelation('QuestionnaireRun', cardinality='**'),
+                        name='based_on')
+Diagnostic.add_relation(SubjectRelation('Scan', cardinality='**'),
+                        name='based_on')
+Diagnostic.add_relation(SubjectRelation('GenomicMeasure', cardinality='**'),
+                        name='based_on')
+TechnicalAnalysis.add_relation(SubjectRelation('QuestionnaireRun', cardinality='**', composite='object'),
+                               name='performed_on')
+TechnicalAnalysis.add_relation(SubjectRelation('Scan', cardinality='**', composite='object'),
+                               name='performed_on')
+TechnicalAnalysis.add_relation(SubjectRelation('GenomicMeasure', cardinality='**', composite='object'),
+                               name='performed_on')
 
 
 # ProcessingRun -> Measure
@@ -41,17 +55,17 @@ ProcessingRun.add_relation(SubjectRelation('GenomicMeasure', cardinality='**'),
 
 # Maesure -> Subject
 QuestionnaireRun.add_relation(SubjectRelation(('Subject', 'SubjectGroup'), cardinality='1*',
-                                              inlined=True, composite='object'), name='concerns')
-Scan.add_relation(SubjectRelation(('Subject', 'SubjectGroup'), cardinality='1*', inlined=True,
-                                  composite='object'), name='concerns')
-GenomicMeasure.add_relation(SubjectRelation(('Subject', 'SubjectGroup'), cardinality='1*', inlined=True,
-                                            composite='object'), name='concerns')
+                                              inlined=True), name='concerns')
+Scan.add_relation(SubjectRelation(('Subject', 'SubjectGroup'), cardinality='1*',
+                                  inlined=True), name='concerns')
+GenomicMeasure.add_relation(SubjectRelation(('Subject', 'SubjectGroup'), cardinality='1*',
+                                            inlined=True), name='concerns')
 
 # Assessment -> Measure
 # TODO: Determine the status of Assessment wrt. QuestionnaireRun, Scan, GenomicMeasure in 'uses'
-Assessment.add_relation(SubjectRelation('QuestionnaireRun', cardinality='**'), name='uses')
-Assessment.add_relation(SubjectRelation('Scan', cardinality='**'), name='uses')
-Assessment.add_relation(SubjectRelation('GenomicMeasure', cardinality='**'), name='uses')
+Assessment.add_relation(SubjectRelation('QuestionnaireRun', cardinality='**', composite='subject'), name='uses')
+Assessment.add_relation(SubjectRelation('Scan', cardinality='**', composite='subject'), name='uses')
+Assessment.add_relation(SubjectRelation('GenomicMeasure', cardinality='**', composite='subject'), name='uses')
 
 Assessment.add_relation(SubjectRelation('QuestionnaireRun', cardinality='?*', composite='subject'), name='generates')
 Assessment.add_relation(SubjectRelation('Scan', cardinality='?*', composite='subject'), name='generates')
@@ -78,17 +92,30 @@ QuestionnaireRun.add_relation(SubjectRelation('Device', cardinality='?*', inline
 Scan.add_relation(SubjectRelation('Device', cardinality='?*', inlined=True), name='uses_device')
 GenomicMeasure.add_relation(SubjectRelation('Device', cardinality='?*', inlined=True), name='uses_device')
 
-# Measure -> ExternalResources
+# Measure -> Files
 # Questionnaire may have some specifications files
-Questionnaire.add_relation(SubjectRelation('ExternalResource', cardinality='*1',
-                                           composite='subject'), name='external_resources')
+Questionnaire.add_relation(SubjectRelation(('File', 'FileSet', 'ExternalFile'),
+                                           cardinality='**', composite='subject'),
+                           name='configuration_files')
 # Some questionnaire run could have specific results files (subject dependant)
-QuestionnaireRun.add_relation(SubjectRelation('ExternalResource', cardinality='*1',
-                                              composite='subject'), name='external_resources')
-Scan.add_relation(SubjectRelation('ExternalResource', cardinality='*1',
-                                  composite='subject'), name='external_resources')
-GenomicMeasure.add_relation(SubjectRelation('ExternalResource', cardinality='*1',
-                                            composite='subject'), name='external_resources')
+QuestionnaireRun.add_relation(SubjectRelation(('File', 'FileSet', 'ExternalFile'),
+                                              cardinality='**', composite='subject'),
+                              name='results_files')
+QuestionnaireRun.add_relation(SubjectRelation(('File', 'FileSet', 'ExternalFile'),
+                                              cardinality='**', composite='subject'),
+                              name='configuration_files')
+Scan.add_relation(SubjectRelation(('File', 'FileSet', 'ExternalFile'),
+                                  cardinality='**', composite='subject'),
+                  name='results_files')
+Scan.add_relation(SubjectRelation(('File', 'FileSet', 'ExternalFile'),
+                                  cardinality='**', composite='subject'),
+                  name='configuration_files')
+GenomicMeasure.add_relation(SubjectRelation(('File', 'FileSet', 'ExternalFile'),
+                                            cardinality='**', composite='subject'),
+                            name='results_files')
+GenomicMeasure.add_relation(SubjectRelation(('File', 'FileSet', 'ExternalFile'),
+                                            cardinality='**', composite='subject'),
+                            name='configuration_files')
 
 # Various relations
 Questionnaire.add_relation(SubjectRelation('ScoreDefinition', cardinality='*?'), name='definitions')
@@ -106,12 +133,13 @@ CWUser.add_relation(String(maxsize=512, fulltextindexed=True), name='extra_infos
 # Comments for entities
 class comments(RelationDefinition):
     subject = 'Comment'
-    object = COMMENTED_ENTITIES
+    object = ('Scan', 'GenomicMeasure', 'QuestionnaireRun')
     composite='object'
 
+
 # Links to "Wikis" / Cards
 class wiki(RelationDefinition):
-    subject = WIKI_ENTITIES
+    subject = ('Question', 'Questionnaire', 'Study', 'ScoreDefinition')
     object = 'Card'
     cardinality = '**'
     composite='subject'
