@@ -17,6 +17,5 @@
 # with this program. If not, see <http://www.gnu.org/licenses/
 
 # Bootswatch css
-STYLESHEETS += [data('bootstrap/css/bootstrap.css'),
-                data('cubes.brainomics.css'),]
+STYLESHEETS += [data('cubes.brainomics.css'),]
 JAVASCRIPTS += [data('cubes.brainomics.js'),]
