@@ -17,12 +17,11 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from cubicweb.web.action import Action
-from cubicweb.predicates import is_instance, nonempty_rset, anonymous_user, match_user_groups
+from cubicweb.predicates import (is_instance, nonempty_rset, anonymous_user,
+                                 match_user_groups, relation_possible)
 from cubicweb.web.views.actions import (CopyAction, ModifyAction, DeleteAction,
                                         ManagePermissionsAction, AddRelatedActions)
 
-
-from cubes.brainomics import ALL_MEASURES, COMMENTED_ENTITIES, WIKI_ENTITIES
 from cubes.brainomics.views.download import (CSV_DOWNLOADABLE, XCEDE_DOWNLOADABLE,
                                              ZIP_DOWNLOADABLE, JSON_DOWNLOADABLE)
 
@@ -40,7 +39,7 @@ class BrainomicsAbstractAdminAction(Action):
 
 class BrainomicsWikiAdminAction(BrainomicsAbstractAdminAction):
     __regid__ = 'ctx-admin-link-wiki'
-    __select__ = BrainomicsAbstractAdminAction.__select__ & is_instance(*WIKI_ENTITIES)
+    __select__ = BrainomicsAbstractAdminAction.__select__ & relation_possible('wiki')
     title = _('Update wiki')
 
     def url(self):
@@ -51,7 +50,7 @@ class BrainomicsWikiAdminAction(BrainomicsAbstractAdminAction):
 
 class BrainomicsCommentAdminAction(BrainomicsAbstractAdminAction):
     __regid__ = 'ctx-admin-link-comment'
-    __select__ = BrainomicsAbstractAdminAction.__select__ & is_instance(*COMMENTED_ENTITIES)
+    __select__ = BrainomicsAbstractAdminAction.__select__ & relation_possible('comments', role='object')
     title = _('Add comment')
 
     def url(self):
