@@ -24,29 +24,15 @@ from cubicweb.predicates import (none_rset, one_line_rset, is_instance, nonempty
                                  anonymous_user, relation_possible)
 from cubicweb.web import component
 from cubicweb.web.views import facets
-from cubicweb.web.views.boxes import SearchBox, EditBox
+from cubicweb.web.views.boxes import EditBox
 from cubicweb.web.views.bookmark import BookmarksBox
-from cubicweb.web.views.basecomponents import ApplicationName
+from cubicweb.web.views.basecomponents import ApplicationName, HeaderComponent
 
-from cubes.brainomics import COMMENTED_ENTITIES, WIKI_ENTITIES
 from cubes.brainomics.views.download import ALL_DOWNLOADABLE
 
 LINKED_ENTITIES = ('Subject',)
 
 
-################################################################################
-### SEARCHBOX ##################################################################
-################################################################################
-class BrainomicsSearchBox(SearchBox):
-    """display a box with a simple search form
-    """
-    context = _('header-center')
-
-    def render(self, w):
-        _('Search')
-        self.render_body(w)
-
-
 ###############################################################################
 ### NAVIGATION BOXES ##########################################################
 ###############################################################################
@@ -150,6 +136,24 @@ class BrainomicsLinksCenters(BrainomicsLinksDropdown):
         return centers
 
 
+class BrainomicsLinksBrowse(BrainomicsLinksDropdown):
+    """ Component used to display browser
+    """
+    __select__ = BrainomicsLinksDropdown.__select__ & is_instance('Subject')
+    __regid__ = 'navtoolbar-browse-ctx'
+
+    def get_title(self):
+        return self._cw._('Browse')
+
+    def related_infos(self, rset):
+        possible_actions = self._cw.vreg['actions'].possible_actions(self._cw, self.cw_rset)
+        links = set()
+        for link in list(possible_actions.get('browse-links', [])):
+            print link.url()
+            links.add((link.url(), link.title))
+        return links
+
+
 ###############################################################################
 ### ADMIN ACTION/BOX ##########################################################
 ###############################################################################
@@ -228,9 +232,10 @@ class BrainomicsResultsFileBox(component.CtxComponent):
         w(u'<h4>%s</h4>' % self._cw._('Results files'))
         w(u'<ul>')
         for _file in entity.results_file:
+            title = _file.dc_title().rsplit('/')[-1]
             w(u'<li>%s<a href="%s" title="%s">%s</a></li>'
               % (_file.view('icon'), _file.absolute_url(),
-                 xml_escape(_file.dc_title()), xml_escape(_file.dc_title()[:20]+'...')))
+                 xml_escape(title), xml_escape(title[:15]+'...')))
         w(u'</ul>')
         w(u'</div>')
 
@@ -241,18 +246,8 @@ class BrainomicsResultsFileBox(component.CtxComponent):
 facets.FilterBox.bk_linkbox_template = u'<p class="btn btn-primary btn-facet">%s</p>'
 
 
-###############################################################################
-### REGISTRATION CALLBACK #####################################################
-###############################################################################
-BookmarksBox.__select__ = BookmarksBox.__select__ & match_user_groups('users', 'managers')
-ApplicationName.context = 'header-left'
-
-
 def registration_callback(vreg):
-    vreg.register_all(globals().values(), __name__, (BrainomicsSearchBox,
-                                                     BrainomicsEditBox,
-                                                     ))
-    vreg.register_and_replace(BrainomicsSearchBox, SearchBox)
+    vreg.register_all(globals().values(), __name__, (BrainomicsEditBox,))
     vreg.register_and_replace(BrainomicsEditBox, EditBox)
     # Unregister breadcrumbs
     from cubicweb.web.views.ibreadcrumbs import (BreadCrumbEntityVComponent,
@@ -268,6 +263,3 @@ def registration_callback(vreg):
     from cubicweb.web.views.basecomponents import ApplLogo, AnonUserStatusLink
     vreg.unregister(ApplLogo)
     vreg.unregister(AnonUserStatusLink)
-    # Remove got rythm
-    from cubicweb.web.views.actions import GotRhythmAction
-    vreg.unregister(GotRhythmAction)
