@@ -20,23 +20,45 @@ from logilab.mtconverter import xml_escape
 
 from cubicweb.predicates import is_instance
 from cubicweb.view import EntityView
-from cubicweb.web.views.baseviews import ListView
+from cubicweb.web.views.baseviews import ListView, SameETypeListView
 
 
-###############################################################################
-### LIST VIEW #################################################################
-###############################################################################
 class BrainomicsListView(ListView):
 
     def call(self, klass=None, title=None, subvid=None, listid=None, **kwargs):
-        super(BrainomicsListView, self).call(klass="unstyled stripped",
+        super(BrainomicsListView, self).call(klass=klass or 'list-unstyled',
                                              title=title, subvid=subvid,
                                              listid=listid, **kwargs)
 
 
-###############################################################################
-### CARD VIEW #################################################################
-###############################################################################
+class BrainomicsSameETypeListView(SameETypeListView):
+
+    def call(self, klass='list-striped', **kwargs):
+        super(BrainomicsSameETypeListView, self).call(klass='list-unstyled', **kwargs)
+
+
+class BrainomicsAdmissionView(EntityView):
+    __regid__ = 'admission-view'
+    __select__ = EntityView.__select__ & is_instance('Admission')
+
+    def cell_call(self, row, col):
+        entity = self.cw_rset.get_entity(row, col)
+        study = entity.admission_in
+        w = self.w
+        w(u'<ul class="list-group">')
+        w(u'<div class="panel panel-default">')
+        w(u'<div class="panel-heading">%s (%s %s)</div>' % (entity.dc_title(),
+                                                            self._cw._('see study'),
+                                                            entity.admission_in[0].view('incontext')))
+        w(u'<div class="panel-body">')
+        w(u'<ul>')
+        for step in entity.reverse_step_of:
+            w(u'<li>%s</li>' % step.dc_title())
+        w(u'</ul>')
+        w(u'</div>')
+        w(u'</div>')
+
+
 class BrainomicsCardDocumentation(EntityView):
     __regid__ = 'documentation_card'
     __select__ = EntityView.__select__ & is_instance('Card')
@@ -126,5 +148,8 @@ class BrainomicsAggregatedView(EntityView):
 
 
 def registration_callback(vreg):
-    vreg.register_all(globals().values(), __name__, (BrainomicsListView,))
+    vreg.register_all(globals().values(), __name__, (BrainomicsListView,
+                                                     BrainomicsSameETypeListView))
     vreg.register_and_replace(BrainomicsListView, ListView)
+    vreg.register_and_replace(BrainomicsSameETypeListView, SameETypeListView)
+
