@@ -197,6 +197,33 @@ class QuestionTableView(EntityTableView):
     def render_answers(w, entity):
         w(u'<a href="%s">%s</a>' % (xml_escape(entity.absolute_url()),
                                     _('See detailed question')))
-    
+
     column_renderers = {'question': EntityTableColRenderer(renderfunc=render_question),
                         'answers': EntityTableColRenderer(renderfunc=render_answers)}
+
+
+###############################################################################
+### DIAGNOSTIC/ANALYSIS #######################################################
+###############################################################################
+class DiagnosticsTableView(EntityTableView):
+    __select__ = EntityTableView.__select__ & is_instance('Diagnostic')
+    __regid__ = 'diagnostics-table-view'
+
+    columns = ['diagnostic_date', 'conclusion', 'diagnostic_location',
+               'diagnosed_disease', 'based_on']
+    column_renderers = {'diagnostic_location': RelationColRenderer(role='subject', vid='incontext'),
+                        'diagnosed_disease': RelationColRenderer(role='subject', vid='incontext'),
+                        'technique_type': RelationColRenderer(role='subject', vid='incontext'),
+                        'based_on': RelationColRenderer(role='subject', vid='incontext'),
+                       }
+
+
+class TechnicalAnalysisTableView(EntityTableView):
+    __select__ = EntityTableView.__select__ & is_instance('TechnicalAnalysis')
+    __regid__ = 'analysis-table-view'
+
+    columns = ['protocols', 'technique_type', 'results', 'conclusion', 'analysis_date', 'performed_on']
+    column_renderers = {'protocols': RelationColRenderer(role='subject', vid='incontext'),
+                        'technique_type': RelationColRenderer(role='subject', vid='incontext'),
+                        'performed_on': RelationColRenderer(role='subject', vid='incontext'),
+                       }
